aboutsummaryrefslogtreecommitdiffstats
path: root/src/passphrase.c
diff options
context:
space:
mode:
authorMattias Andrée <maandree@operamail.com>2013-11-22 10:05:44 +0100
committerMattias Andrée <maandree@operamail.com>2013-11-22 10:05:44 +0100
commitfd91b35c5604b669668a15ec5beadcc36958d08d (patch)
tree2557f9761b21803579e7eb75320897b78882b46a /src/passphrase.c
parentfirst version (diff)
downloadlibpassphrase-fd91b35c5604b669668a15ec5beadcc36958d08d.tar.gz
libpassphrase-fd91b35c5604b669668a15ec5beadcc36958d08d.tar.bz2
libpassphrase-fd91b35c5604b669668a15ec5beadcc36958d08d.tar.xz
use namespacing
Signed-off-by: Mattias Andrée <maandree@operamail.com>
Diffstat (limited to 'src/passphrase.c')
-rw-r--r--src/passphrase.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/passphrase.c b/src/passphrase.c
index a3ca289..724ff09 100644
--- a/src/passphrase.c
+++ b/src/passphrase.c
@@ -38,7 +38,7 @@ static struct termios saved_stty;
*
* @return The passphrase, should be wiped `free`:ed, `NULL` on error
*/
-char* get_passphrase(void)
+char* passphrase_read(void)
{
/* malloc and realloc returns NULL if we run out of memory,
we will not do that under normal usecases, if we do, it
@@ -78,9 +78,9 @@ char* get_passphrase(void)
/**
* Disable echoing and do anything else to the terminal settnings `get_passphrase` requires
*/
-void disable_echo(void)
+void passphrase_disable_echo(void)
{
struct termios stty;
@@ -92,9 +92,9 @@ void disable_echo(void)
/**
* Undo the actions of `disable_echo`
*/
-void reenable_echo(void)
+void passphrase_reenable_echo(void)
{
tcsetattr(STDIN_FILENO, TCSAFLUSH, &saved_stty);
}
@@ -78,9 +78,9 @@ char* get_passphrase(void)
/**
- * Disable echoing and do anything else to the terminal settnings `get_passphrase` requires
+ * Disable echoing and do anything else to the terminal settnings `passphrase_read` requires
*/
@@ -92,9 +92,9 @@ void disable_echo(void)
/**
- * Undo the actions of `disable_echo`
+ * Undo the actions of `passphrase_disable_echo`
*/